@@ -21,20 +21,21 @@ pub(crate) use base::{APIResponse, BaseClient};
 
 pub use calendar::{
     CreateCalendarInput, DeleteCalendarInput, GetCalendarEventsInput, GetCalendarInput,
-    UpdateCalendarInput,
+    SyncCalendarInput, UpdateCalendarInput,
 };
 pub use event::{
     CreateEventInput, DeleteEventInput, GetEventInput, GetEventsInstancesInput, UpdateEventInput,
 };
 pub use nettu_scheduler_domain::{
     providers::google::*, providers::outlook::*, scheduling::RoundRobinAlgorithm, BusyCalendar,
-    CalendarEventReminder, RRuleOptions, ScheduleRule, ServiceMultiPersonOptions, SyncedCalendar,
-    SyncedCalendarProvider, TimePlan, ID,
+    CalendarEventReminder, IntegrationProvider, RRuleOptions, ScheduleRule,
+    ServiceMultiPersonOptions, SyncedCalendar, TimePlan, ID,
 };
 pub use schedule::{CreateScheduleInput, UpdateScheduleInput};
 pub use service::{
-    AddServiceUserInput, CreateBookingIntendInput, CreateServiceInput, GetServiceBookingSlotsInput,
-    RemoveBookingIntendInput, RemoveServiceUserInput, UpdateServiceInput, UpdateServiceUserInput,
+    AddBusyCalendar, AddServiceUserInput, CreateBookingIntendInput, CreateServiceInput,
+    GetServiceBookingSlotsInput, RemoveBookingIntendInput, RemoveBusyCalendar,
+    RemoveServiceUserInput, UpdateServiceInput, UpdateServiceUserInput,
 };
 pub use shared::{KVMetadata, MetadataFindInput};
 pub use user::CreateUserInput;
