@@ -13,7 +13,6 @@ pub struct ServiceClient {
 pub struct AddServiceUserInput {
     pub service_id: ID,
     pub user_id: ID,
-    pub busy: Option<Vec<BusyCalendar>>,
     pub availability: Option<TimePlan>,
     pub buffer_after: Option<i64>,
     pub buffer_before: Option<i64>,
@@ -21,10 +20,21 @@ pub struct AddServiceUserInput {
     pub furthest_booking_time: Option<i64>,
 }
 
+pub struct AddBusyCalendar {
+    pub service_id: ID,
+    pub user_id: ID,
+    pub calendar: BusyCalendar,
+}
+
+pub struct RemoveBusyCalendar {
+    pub service_id: ID,
+    pub user_id: ID,
+    pub calendar: BusyCalendar,
+}
+
 pub struct UpdateServiceUserInput {
     pub service_id: ID,
     pub user_id: ID,
-    pub busy: Option<Vec<BusyCalendar>>,
     pub availability: Option<TimePlan>,
     pub buffer_after: Option<i64>,
     pub buffer_before: Option<i64>,
@@ -222,7 +232,6 @@ impl ServiceClient {
             availability: input.availability,
             buffer_after: input.buffer_after,
             buffer_before: input.buffer_before,
-            busy: input.busy,
             closest_booking_time: input.closest_booking_time,
             furthest_booking_time: input.furthest_booking_time,
         };
@@ -246,7 +255,6 @@ impl ServiceClient {
             availability: input.availability,
             buffer_after: input.buffer_after,
             buffer_before: input.buffer_before,
-            busy: input.busy,
             closest_booking_time: input.closest_booking_time,
             furthest_booking_time: input.furthest_booking_time,
         };
@@ -259,4 +267,38 @@ impl ServiceClient {
             )
             .await
     }
+
+    pub async fn add_busy_calendar(
+        &self,
+        input: AddBusyCalendar,
+    ) -> APIResponse<add_busy_calendar::APIResponse> {
+        let body = add_busy_calendar::RequestBody {
+            busy: input.calendar,
+        };
+
+        self.base
+            .put(
+                body,
+                format!("service/{}/users/{}/busy", input.service_id, input.user_id),
+                StatusCode::OK,
+            )
+            .await
+    }
+
+    pub async fn remove_busy_calendar(
+        &self,
+        input: AddBusyCalendar,
+    ) -> APIResponse<remove_busy_calendar::APIResponse> {
+        let body = remove_busy_calendar::RequestBody {
+            busy: input.calendar,
+        };
+
+        self.base
+            .delete_with_body(
+                body,
+                format!("service/{}/users/{}/busy", input.service_id, input.user_id),
+                StatusCode::OK,
+            )
+            .await
+    }
 }
